@@ -1,5 +1,5 @@
 package Dancer2::Plugin::MarkdownFilesToHTML ;
-$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.008';
+$Dancer2::Plugin::MarkdownFilesToHTML::VERSION = '0.009';
 use 5.010; use strict; use warnings;
 
 use Carp;
@@ -12,7 +12,6 @@ use Dancer2::Plugin;
 use HTML::TreeBuilder;
 use File::Spec::Functions qw(catfile);
 use Text::Markdown::Hoedown;
-use Dancer2::Plugin::DebugDump;
 
 plugin_keywords qw( mdfile_2html mdfiles_2html );
 
@@ -21,6 +20,7 @@ sub BUILD {
   my $s      = shift;
   my $app    = $s->app;
   my $config = $s->config;
+  #print Dumper $config;
 
   # add routes from config file
   foreach my $route (@{$config->{routes}}) {
@@ -163,28 +163,28 @@ sub mdfile_2html {
   }
 
   # generate the cache if it doesn't exist
-  if (!-d 'lib/data/markdown_files/cache') {
+  if (!-d 'lib/data/markdown_files/cache' && $ENV{DANCER_ENVIRONMENT} ne 'testing') {
     make_path 'lib/data/markdown_files'
   }
 
-  # check the cache for a hit by comparing timestemps of cached file and
-  # markdown file
+  # generate unique cache file name appended with values of two options
   my $cache_file = $file;
   $cache_file =~ s/\///g;
-  $cache_file = "lib/data/markdown_files/cache/$cache_file";
+  my $cache_dir = $ENV{DANCER_ENVIRONMENT} eq 'testing' ? 'xt' : 'lib';
+  $cache_file = "$cache_dir/data/markdown_files/cache/$cache_file"
+                . $options->{linkable_headers}
+                . $options->{generate_toc};
+
+  # check for cache hit
   if (-f $cache_file && $options->{cache}) {
     if (-M $cache_file eq -M $file) {
       my $data = retrieve $cache_file;
-      if ($data->{linkable_headers} == $options->{linkable_headers}
-          && $data->{generate_toc}  == $options->{generate_toc}) {
-        return ($data->{html}, $data->{toc});
-      }
+      return ($data->{html}, $data->{toc});
     }
   }
 
-  # no cache hit so we must parse the file
-
-  # fetch the file and parse it
+  # no cache hit so we parse the file
+  # slurp the file and parse it with Hoedown's markdown function
   my $markdown = '';
   {
     local $/;
@@ -192,10 +192,10 @@ sub mdfile_2html {
     $markdown = <$md>;
     close $md;
   }
-  # markdown function supplied by Hoedown module
   my $out = markdown($markdown, extensions => HOEDOWN_EXT_FENCED_CODE);
 
-  # TOC makes linkable_headers true so we just need to test linkable_headers option
+  # See if we can cache and return the output without further processing
+  # generate_toc makes linkable_headers true so we just need to test linkable_headers option
   if (!$options->{linkable_headers}) {
     return $s->_cache_data($options, $cache_file, $file, $out);
   }
@@ -219,6 +219,15 @@ sub mdfile_2html {
     }
   }
 
+  # add a special class for code that has no siblings to give it special styling
+  # TODO: document this
+  my @code_els = $tree->find_by_tag_name('code');
+  foreach my $code_el (@code_els) {
+    if (!$code_el->left && !$code_el->right) {
+      $code_el->attr('class' => 'single-line');
+    }
+  }
+
   # Generate the final HTML from trees and cache
   # "guts" method gets rid of <html> and <body> tags added by TreeBuilder
   return $s->_cache_data($options, $cache_file, $file,
@@ -230,10 +239,7 @@ sub _cache_data {
   $toc //= '';
 
   if ($options->{cache}) {
-    store { html => $content, toc => $toc,
-            linkable_headers => $options->{linkable_headers},
-            generate_toc => $options->{generate_toc} },
-            $cache_file;
+    store { html => $content, toc => $toc }, $cache_file;
     my ($read, $write) = (stat($file))[8,9];
     utime($read, $write, $cache_file);
   }
@@ -253,7 +259,7 @@ Dancer2::Plugin::MarkdownFilesToHTML
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -537,8 +543,6 @@ Now only the four files listed get processed in the order listed above.
 
 =item * L<Dancer2::Plugin|Dancer2::Plugin>
 
-=item * L<Dancer2::Plugin::DebugDump|Dancer2::Plugin::DebugDump>
-
 =item * L<Data::Dumper|Data::Dumper>
 
 =item * L<Encode|Encode>
